@@ -9,12 +9,12 @@ describe 'vitrage::db' do
         :db_max_retries          => '<SERVICE DEFAULT>',
         :connection              => 'mysql+pymysql://vitrage:secrete@localhost:3306/vitrage',
         :connection_recycle_time => '<SERVICE DEFAULT>',
-        :min_pool_size           => '<SERVICE DEFAULT>',
         :max_pool_size           => '<SERVICE DEFAULT>',
         :max_retries             => '<SERVICE DEFAULT>',
         :retry_interval          => '<SERVICE DEFAULT>',
         :max_overflow            => '<SERVICE DEFAULT>',
         :pool_timeout            => '<SERVICE DEFAULT>',
+        :mysql_enable_ndb        => '<SERVICE DEFAULT>',
       )}
     end
 
@@ -23,13 +23,13 @@ describe 'vitrage::db' do
         {
           :database_connection              => 'mysql+pymysql://vitrage:vitrage@localhost/vitrage',
           :database_connection_recycle_time => '3601',
-          :database_min_pool_size           => '2',
           :database_db_max_retries          => '-1',
           :database_max_retries             => '11',
           :database_retry_interval          => '11',
           :database_max_pool_size           => '11',
           :database_max_overflow            => '21',
           :database_pool_timeout            => '21',
+          :mysql_enable_ndb                 => true,
         }
       end
 
@@ -39,12 +39,12 @@ describe 'vitrage::db' do
         :db_max_retries          => '-1',
         :connection              => 'mysql+pymysql://vitrage:vitrage@localhost/vitrage',
         :connection_recycle_time => '3601',
-        :min_pool_size           => '2',
         :max_pool_size           => '11',
         :max_retries             => '11',
         :retry_interval          => '11',
         :max_overflow            => '21',
         :pool_timeout            => '21',
+        :mysql_enable_ndb        => true,
       )}
     end
   end
